@@ -1,5 +1,5 @@
 /*
- * Copyright 2007 Romain Beauxis
+ * Copyright 2007-2010 Romain Beauxis
  *
  * This file is part of ocaml-taglib.
  *
@@ -24,7 +24,7 @@
  * your choice, without any of the additional requirements listed in clause 6
  * of the GNU Library General Public License.
  * By "a publicly distributed version of the Library", we mean either the unmodified
- * Library as distributed by INRIA, or a modified version of the Library that is
+ * Library as distributed by The Savonet Team, or a modified version of the Library that is
  * distributed under the conditions defined in clause 3 of the GNU Library General
  * Public License. This exception does not however invalidate any other reasons why
  * the executable file might be covered by the GNU Library General Public License.
@@ -78,8 +78,30 @@ CAMLprim value caml_taglib_priv_value_int(value name)
       CAMLreturn(Val_int(TagLib_File_FLAC)) ;
     if (!strcmp(s,"File_MPC"))
       CAMLreturn(Val_int(TagLib_File_MPC)) ;
+    if (!strcmp(s,"File_OggFlac"))
+      CAMLreturn(Val_int(TagLib_File_OggFlac)) ;
+#ifdef TagLib_File_WavPack
+    if (!strcmp(s,"File_WavPack"))
+      CAMLreturn(Val_int(TagLib_File_WavPack)) ;
+#endif
+#ifdef TagLib_File_Speex
+    if (!strcmp(s,"File_Speex"))
+      CAMLreturn(Val_int(TagLib_File_Speex)) ;
+#endif
+#ifdef TagLib_File_TrueAudio
+    if (!strcmp(s,"File_TrueAudio"))
+      CAMLreturn(Val_int(TagLib_File_TrueAudio)) ;
+#endif
+#ifdef TagLib_File_MP4
+    if (!strcmp(s,"File_MP4"))
+      CAMLreturn(Val_int(TagLib_File_MP4)) ;
+#endif
+#ifdef TagLib_File_ASF
+    if (!strcmp(s,"File_ASF"))
+      CAMLreturn(Val_int(TagLib_File_ASF)) ;
+#endif
 
-  caml_failwith("Invalid value");
+  caml_raise_constant(*caml_named_value("taglib_exn_not_implemented"));
 }
 
 #define Taglib_file_val(v) ((TagLib_File *)v)
@@ -92,15 +114,7 @@ CAMLprim value caml_taglib_file_new(value name)
 {
   CAMLparam1(name);
 
-  int len = caml_string_length(name);
-  char *filename = malloc(len);
-  memcpy(filename, String_val(name), len);
-
-  caml_enter_blocking_section();
-  TagLib_File *f = taglib_file_new(filename) ;
-  caml_leave_blocking_section();
-
-  free(filename);
+  TagLib_File *f = taglib_file_new(String_val(name)) ;
 
   if (f == NULL)
     caml_raise_constant(*caml_named_value("taglib_exn_not_found"));
@@ -112,16 +126,8 @@ CAMLprim value caml_taglib_file_new_type(value name, value type)
 {
   CAMLparam2(name,type);
 
-  int len = caml_string_length(name);
-  char *filename = malloc(len);
-  memcpy(filename, String_val(name), len);
-
-  caml_enter_blocking_section();
   TagLib_File *f =
-    taglib_file_new_type((const char *)String_val(name),Int_val(type)) ;
-  caml_leave_blocking_section();
-
-  free(filename);
+    taglib_file_new_type(String_val(name),Int_val(type)) ;
 
   if (f == NULL)
     caml_raise_constant(*caml_named_value("taglib_exn_not_found"));
@@ -151,7 +157,7 @@ CAMLprim value caml_taglib_file_tag(value f)
 CAMLprim value caml_taglib_file_audioproperties(value f)
 {
   CAMLparam1(f);
-  TagLib_AudioProperties *p = taglib_file_audioproperties(Taglib_file_val(f)) ;
+  const TagLib_AudioProperties *p = taglib_file_audioproperties(Taglib_file_val(f)) ;
 
   if (p == NULL)
     caml_raise_constant(*caml_named_value("taglib_exn_not_found"));
